(-debug-Marker-String-Object-Object this__3078__auto__ & args3824)(-debug-Marker-String-Throwable this__3078__auto__ & args3918)(-error-Marker-String-Object-Object this__3078__auto__ & args3194)(-error-Marker-String-Throwable this__3078__auto__ & args3288)(-info-Marker-String-Object-Object this__3078__auto__ & args3614)(-trace-Marker-String-Object-Object this__3078__auto__ & args4034)(-trace-Marker-String-Throwable this__3078__auto__ & args4128)(-warn-Marker-String-Object-Object this__3078__auto__ & args3404)(define-methods method-name level)Defines the various overloads for a given logging method (e.g., -info). Several have the same arity so we use an undocumented Clojure feature [1] to specify their type signatures. This macro expands into a (do ...) sexpr containing a defn for each of the ten variants declared in the Logger interface. [1] https://groups.google.com/d/embed/msg/clojure/KmNbLo8xTSs/d1Rs3Cs6DbAJ
Defines the various overloads for a given logging method (e.g., -info). Several have the same arity so we use an undocumented Clojure feature [1] to specify their type signatures. This macro expands into a (do ...) sexpr containing a defn for each of the ten variants declared in the Logger interface. [1] https://groups.google.com/d/embed/msg/clojure/KmNbLo8xTSs/d1Rs3Cs6DbAJ
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |